==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/cy.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Rheoli Paramedrau Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "rheoli Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Lled Delwedd Llawn-Maint");
define('MANAGE_GALLERY_FULL_HEIGHT', "Llawn-Maint y llun Uchder");
define('MANAGE_GALLERY_THUMB_WIDTH', "Lled Image Thumbnail");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Uchder");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Cadw Thumb Cymhareb Agwedd");
define('MANAGE_GALLERY_SHOW_TITLES', "Dangos Teitlau");
define('MANAGE_GALLERY_DISABLE_SORT', "Trefnu Analluogi");
define('MANAGE_GALLERY_DELETE_IMAGE', "Dileu Delwedd");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Arbed Trefnu Archebu");
define('MANAGE_GALLERY_PUBLISH_MSG', "Cliciwch &#39;Diweddaru&#39; i gyhoeddi <br /> eich delweddau llwytho i fyny.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Mae&#39;r holl ddelweddau wedi cael eu newid maint a lleoliadau wedi eu cadw.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Bu gwall newid maint y delweddau neu arbed lleoliadau.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Eich delwedd (au) wedi cael ei llwytho i fyny.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Bu gwall lanlwytho eich delwedd (au).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Nid yw&#39;r ffeil rydych yn ceisio ei llwytho yn ddelwedd.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Mae&#39;r ffeil rydych yn ceisio ei llwytho yn rhy fawr.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Mae&#39;r teitl wedi ei gadw.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ydych chi&#39;n siŵr eich bod eisiau dileu&#39;r llun");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Mae&#39;r ddelwedd wedi cael ei ddileu.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Bu gwall ddileu&#39;r ddelwedd.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Arbed paramedrau a newid maint delweddau, arhoswch ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Llwytho i fyny, arhoswch ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Nid yw&#39;r drefn wedi ei gadw. Ydych chi eisiau achub y drefn?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Mae&#39;r gorchymyn ddelwedd fath wedi ei gadw.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Roedd arbed y math ddelwedd camgymeriadau.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/cy.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Rheoli Paramedrau Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "rheoli Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Lled Delwedd Llawn-Maint");
define('MANAGE_GALLERY_FULL_HEIGHT', "Llawn-Maint y llun Uchder");
define('MANAGE_GALLERY_THUMB_WIDTH', "Lled Image Thumbnail");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Uchder");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Cadw Thumb Cymhareb Agwedd");
define('MANAGE_GALLERY_SHOW_TITLES', "Dangos Teitlau");
define('MANAGE_GALLERY_DISABLE_SORT', "Trefnu Analluogi");
define('MANAGE_GALLERY_DELETE_IMAGE', "Dileu Delwedd");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Arbed Trefnu Archebu");
define('MANAGE_GALLERY_PUBLISH_MSG', "Cliciwch &#39;Diweddaru&#39; i gyhoeddi <br /> eich delweddau llwytho i fyny.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Mae&#39;r holl ddelweddau wedi cael eu newid maint a lleoliadau wedi eu cadw.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Bu gwall newid maint y delweddau neu arbed lleoliadau.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Eich delwedd (au) wedi cael ei llwytho i fyny.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Bu gwall lanlwytho eich delwedd (au).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Nid yw&#39;r ffeil rydych yn ceisio ei llwytho yn ddelwedd.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Mae&#39;r ffeil rydych yn ceisio ei llwytho yn rhy fawr.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Mae&#39;r teitl wedi ei gadw.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ydych chi&#39;n siŵr eich bod eisiau dileu&#39;r llun");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Mae&#39;r ddelwedd wedi cael ei ddileu.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Bu gwall ddileu&#39;r ddelwedd.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Arbed paramedrau a newid maint delweddau, arhoswch ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Llwytho i fyny, arhoswch ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Nid yw&#39;r drefn wedi ei gadw. Ydych chi eisiau achub y drefn?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Mae&#39;r gorchymyn ddelwedd fath wedi ei gadw.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Roedd arbed y math ddelwedd camgymeriadau.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Mae&#39;r ffeil rydych chi&#39;n ceisio ei huwchlwytho yn fwy na&#39;r gosodiadau PHP &#39;upload_max_filesize&#39; neu&#39;r &#39;post_max_size&#39;. Cysylltwch â gweinyddwr eich system i gynyddu&#39;r terfynau hyn.");
?>
